@@ -1,6 +1,6 @@
 # lib/dado.py
 import random
-from lucidaflow..lucida_symbols import VarSymbol, BuiltInFunctionSymbol, ScopedSymbolTable, BuiltInTypeSymbol
+from lucidaflow.lucida_symbols import VarSymbol, BuiltInFunctionSymbol, ScopedSymbolTable, BuiltInTypeSymbol
 
 # --- Lógica de Runtime ---
 def lf_d6(args):
