@@ -1,6 +1,6 @@
 # lib/web.py
 import requests
-from lucidaflow..lucida_symbols import VarSymbol, BuiltInFunctionSymbol, ScopedSymbolTable, BuiltInTypeSymbol
+from lucidaflow.lucida_symbols import VarSymbol, BuiltInFunctionSymbol, ScopedSymbolTable, BuiltInTypeSymbol
 
 # --- PARTE 1: Lógica de Runtime ---
 
